% WARNING: Running this code removes all variables from the current
% workspace, and closes current figures.
clear all
close all
home

% Modified by Jiayi Sun 2022-06-07
%{
An example MATLAB code for the dataset, Groon_2015, that plots the mean
absorbance, mean Zmag, and mean Zang for the data. There is only one session per subject, so this
code shows a simple way to plot without having to take into account
multiple sessions.

Made with MATLAB R2022a
Please install Statistics Toolbox to use some functions inside the code.
%}

% Load in tables from database via mySQL
% Note: file name should match the file name you saved on your computer
data = readtable('WAI_Measurements_2022-06-06.csv');
Subjects_Table = readtable('WAI_Subjects_2022-06-06.csv');

% Only use PI we are checking 
PI = 'Groon_2015';
data=data(strcmp(data.Identifier, PI),:);
Subjects_Table = Subjects_Table(strcmp(Subjects_Table.Identifier, PI),:);


% Get frequencies used for measurements
Frequency = unique(data.Frequency);
Groon_freqs = Frequency;
% Get subject numbers 
SubjectNumbers=unique(data.SubjectNumber);
% Get the number of subjects
NumberSubjects=length(SubjectNumbers);

% Make sure number of subjects is correct from subjects table, should be 21
NumSubs = length(unique(Subjects_Table.SubjectNumber)); %it's 21, so it's correct


% Groon only has one measurement per subject, so to get mean value, we
% can average the absorbance/Zmag/Zang over each frequency
% to do it this way, first make sure the data only has one measurement per
% subject

% Find the mean absorbance
Absorbance = [];
% Go through all the frequencies and find the mean absorbance for each frequency
for freq_index = 1:length(Groon_freqs)
    % Find all the rows for the frequency each loop
    freq_rows = find(data.Frequency==Groon_freqs(freq_index));
    % Get the absorbances at each frequency
    Absorbance = [Absorbance; data.Absorbance(freq_rows).'];  
end
% Get the mean absorbance at each frequency
mean_Abs = nanmean(Absorbance,2);

% Find the mean Zmag
ImpedanceMag = [];
% Go through all the frequencies and find the mean Zmag for each frequency
for freq_index = 1:length(Groon_freqs)
    % Find all the rows for the frequency each loop
    freq_rows = find(data.Frequency==Groon_freqs(freq_index));
    % Get the impedance magnitudes at each frequency
    ImpedanceMag = [ImpedanceMag; data.Zmag(freq_rows).'];  
end
% Get the mean Zmag at each frequency
mean_Zmag = nanmean(ImpedanceMag,2);

% Get the mean Zang (cycles)
ImpedanceAng = [];
% Go through all the frequencies and find the mean Zang for each frequency
for freq_index = 1:length(Groon_freqs)
    % Find all the rows for the frequency each loop
    freq_rows = find(data.Frequency==Groon_freqs(freq_index));
    % Get the impedance angles at each frequency
    ImpedanceAng = [ImpedanceAng; data.Zang(freq_rows).'];   
end
% Get the mean absorbance at each frequency
mean_Zang = nanmean(ImpedanceAng,2);


% Make plots
figure(1)
sgtitle('Groon et al. (2015)', 'FontSize', 20)
% Plot absorbance for all subjects and mean absorbance
% the frequency is coded on the x axis on a log scale 
subplot(332)
semilogx(Frequency, Absorbance, 'm', 'LineWidth', 0.5)
hold on
semilogx(Frequency, mean_Abs, 'b', 'LineWidth', 3)
xlim([100 10000])
ylim([0 1])
xlabel('Frequency (Hz)')
ylabel('Absorbance')
title('Absorbance')
hold off

% Plot Zmag for all subjects and mean Zmag
% the frequency is coded on the x axis on a log scale 
% the mean Zmag is coded on the y axis on a log scale 
subplot(335)
loglog(Frequency, ImpedanceMag, 'm', 'LineWidth', 0.5)
hold on
loglog(Frequency, mean_Zmag, 'b', 'LineWidth', 3)
xlim([100 10000])
xlabel('Frequency (Hz)')
ylabel('Impedance')
title('Magnitude (MKS Ohms)')
hold off

% Plot Zang for all subjects and mean Zang
% the frequency is coded on the x axis on a log scale 
subplot(338)
semilogx(Frequency, ImpedanceAng, 'm', 'LineWidth', 0.5)
hold on
semilogx(Frequency, mean_Zang, 'b', 'LineWidth', 3)
xlim([100 10000])
xlabel('Frequency (Hz)')
ylabel('Angle (cycles)')
title('Impedance')
hold off

